---
jupytext:
  formats: md:myst
  text_representation:
    extension: .md
    format_name: myst
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

(genetic_values_multi_deme_models)=

# Setting up genetic value objects.

NOTE: this will get too long -- split!!

## Case 1: constant effect size, different fitness effects.

## Case 2: different effect sizes, same fitness effects.

## Case 3: different effect sizes, different fitness effects.
